import {Component} from '@angular/core';
import {NshmpLibNgAboutPageComponent} from '@ghsc/nshmp-lib-ng/about';
import {
  ApplicationSections,
  NshmpLibNgDashboardComponent,
  NshmpLibNgDashboardDescriptionComponent,
  NshmpLibNgDashboardTitleComponent,
  NshmpLibNgTemplateComponent,
} from '@ghsc/nshmp-lib-ng/nshmp';

import {apps} from '../../shared/utils/applications.utils';
import {
  designMapApps,
  gmmApps,
  hazardApps,
  navigation,
  ncmApps,
  serviceApps,
  sourceModelApps,
} from '../../shared/utils/navigation.utils';
import {AboutComponent} from './components/about/about.component';

/**
 * Main entrypoint to USGS Earthquake Hazard Toolbox.
 *
 * Dashboard application showing links to all applications.
 */
@Component({
  imports: [
    NshmpLibNgTemplateComponent,
    NshmpLibNgAboutPageComponent,
    NshmpLibNgDashboardComponent,
    NshmpLibNgDashboardTitleComponent,
    NshmpLibNgDashboardDescriptionComponent,
    AboutComponent,
  ],
  selector: 'app-app',
  standalone: true,
  styleUrl: './app.component.scss',
  templateUrl: './app.component.html',
})
export class AppComponent {
  /** Navigation list for menu */
  navigationList = navigation();

  /** Design map apps  */
  private designMapApps = designMapApps();
  /** The GMM applications */
  private gmmApps = gmmApps();
  /** Hazard applications */
  private hazardApps = hazardApps();
  /** NCM apps  */
  private ncmApps = ncmApps();
  /** Source model applications */
  private sourceModelApps = sourceModelApps();
  /** Service applications */
  private serviceApps = serviceApps();

  sections: ApplicationSections[] = [
    {
      sections: [
        {
          applications: this.hazardApps.map(navigation => ({navigation})),
          routerLink: apps().hazard.dashboard.routerLink,
          title: 'Hazard',
        },
        {
          applications: this.serviceApps.map(navigation => ({navigation})),
          title: 'Services',
        },
      ],
    },
    {
      sections: [
        {
          applications: this.sourceModelApps.map(navigation => ({navigation})),
          routerLink: apps().source.dashboard.routerLink,
          title: 'Source Model',
        },
        {
          applications: this.gmmApps.map(navigation => ({navigation})),
          routerLink: apps().gmm.dashboard.routerLink,
          title: 'Ground Motion Models',
        },
        {
          applications: this.designMapApps.map(navigation => ({navigation})),
          routerLink: apps().designMaps.dashboard.routerLink,
          title: 'Design Maps',
        },
        {
          applications: this.ncmApps.map(navigation => ({navigation})),
          routerLink: apps().ncm.dashboard.routerLink,
          title: 'National Crustal Model',
        },
      ],
    },
  ];

  constructor() {}
}
