import {AsyncPipe} from '@angular/common';
import {Component, computed} from '@angular/core';
import {MatTab, MatTabContent, MatTabGroup} from '@angular/material/tabs';
import {gmmUtils} from '@ghsc/nshmp-lib-ng/gmm';
import {NshmpLibNgDataTablePanelComponent} from '@ghsc/nshmp-lib-ng/nshmp';

import {Plots} from '../../models/state.model';
import {AppService} from '../../services/app.service';
import {PlotsComponent} from '../plots/plots.component';

@Component({
  imports: [
    NshmpLibNgDataTablePanelComponent,
    MatTabGroup,
    MatTab,
    MatTabContent,
    PlotsComponent,
    AsyncPipe,
  ],
  selector: 'app-content',
  standalone: true,
  styleUrl: './content.component.scss',
  templateUrl: './content.component.html',
})
export class ContentComponent {
  /** Whether the data has common X values */
  commonXValues = true;
  /** Whether data is shown is exponential form */
  exp = true;

  /** Whether service has been called and data exists */
  hasData = computed(() => this.service.state().serviceResponses?.length > 0);

  /** Table data for table */
  table = computed(() =>
    gmmUtils.plotToTable(
      this.service.state().plots.get(Plots.GROUND_MOTION).plotData,
      this.exp,
      this.commonXValues
    )
  );

  constructor(private service: AppService) {}
}
