import {AsyncPipe} from '@angular/common';
import {Component, computed} from '@angular/core';
import {MatTab, MatTabContent, MatTabGroup} from '@angular/material/tabs';
import {gmmUtils} from '@ghsc/nshmp-lib-ng/gmm';
import {NshmpLibNgDataTablePanelComponent} from '@ghsc/nshmp-lib-ng/nshmp';

import {AppService} from '../../services/app.service';
import {PlotsComponent} from '../plots/plots.component';

/**
 * Application main content with Angular material tabs with:
 *  - Plots tab: GMM vs magnitude plot
 *  - Median data tab: table with GMM vs magnitude median data
 *  - Sigma data tab: table with GMM vs magnitude sigma data
 */
@Component({
  imports: [
    NshmpLibNgDataTablePanelComponent,
    MatTabGroup,
    MatTab,
    MatTabContent,
    PlotsComponent,
    AsyncPipe,
  ],
  selector: 'app-content',
  standalone: true,
  styleUrl: './content.component.scss',
  templateUrl: './content.component.html',
})
export class ContentComponent {
  /** Whether the data has common X values */
  commonXValues = true;
  /** Whether median data is shown is exponential form */
  medianExp = true;
  /** Whether sigma data is shown is exponential form */
  sigmaExp = false;

  /** Whether service has been called and data exists */
  hasData = computed(() => this.service.serviceResponse()?.length > 0);

  /** Table data for mean data */
  meanTable = computed(() => {
    const plot = this.service.meanPlotState();

    return gmmUtils.plotToTable(
      plot.plotData,
      this.medianExp,
      this.commonXValues
    );
  });

  /** Table data for sigma table */
  sigmaTable = computed(() => {
    const plot = this.service.sigmaPlotState();

    return gmmUtils.plotToTable(
      plot.plotData,
      this.medianExp,
      this.commonXValues
    );
  });

  constructor(public service: AppService) {}
}
