import {AsyncPipe} from '@angular/common';
import {Component, computed} from '@angular/core';
import {MatTab, MatTabContent, MatTabGroup} from '@angular/material/tabs';
import {gmmUtils} from '@ghsc/nshmp-lib-ng/gmm';
import {NshmpLibNgDataTablePanelComponent} from '@ghsc/nshmp-lib-ng/nshmp';

import {AppService} from '../../services/app.service';
import {PlotsComponent} from '../plots/plots.component';

/**
 * Application main content with Angular material tabs with:
 *  - Plots tab: GMM response spectra plot
 *  - Median data tab: table with response spectra median data
 *  - Sigma data tab: table with response spectra sigma data
 */
@Component({
  imports: [
    NshmpLibNgDataTablePanelComponent,
    MatTabGroup,
    MatTab,
    MatTabContent,
    PlotsComponent,
    AsyncPipe,
  ],
  selector: 'app-content',
  standalone: true,
  styleUrl: './content.component.scss',
  templateUrl: './content.component.html',
})
export class ContentComponent {
  /** Whether the data has common X values */
  commonXValues = true;
  /** Whether to pad values */
  padValues = true;
  /** Whether sigma data is shown is exponential form */
  sigmaExp = false;
  /** Whether spectra data is shown is exponential form */
  spectraExp = true;

  /** Whether service has been called and data exists */
  hasData = computed(() => this.service.serviceResponse()?.length > 0);

  /** Table data for sigma */
  sigmaTable = computed(() => {
    const plot = this.service.sigmaPlotState();

    return gmmUtils.plotToTable(
      plot.plotData,
      this.sigmaExp,
      this.commonXValues,
      this.padValues,
      plot.xValues
    );
  });

  /** Table data for mean */
  spectraTable = computed(() => {
    const plot = this.service.spectraPlotState();

    return gmmUtils.plotToTable(
      plot.plotData,
      this.spectraExp,
      this.commonXValues,
      this.padValues,
      plot.xValues
    );
  });

  constructor(public service: AppService) {}
}
