import {Component} from '@angular/core';
import {MatButton, MatMiniFabButton} from '@angular/material/button';
import {
  MatCard,
  MatCardActions,
  MatCardContent,
  MatCardHeader,
  MatCardTitle,
} from '@angular/material/card';
import {MatDivider} from '@angular/material/divider';
import {
  MatAccordion,
  MatExpansionPanel,
  MatExpansionPanelHeader,
  MatExpansionPanelTitle,
} from '@angular/material/expansion';
import {MatIcon} from '@angular/material/icon';
import {MatTooltip} from '@angular/material/tooltip';
import {RouterLink} from '@angular/router';
import {YamlPipe} from '@ghsc/nshmp-lib-ng/aws';
import {NshmpService} from '@ghsc/nshmp-lib-ng/nshmp';
import {
  RunNshmpHazHttpPostConfig,
  RunNshmpHazResponseData,
} from '@ghsc/nshmp-utils-ts/libs/aws/run-nshmp-haz';
import {Response} from '@ghsc/nshmp-utils-ts/libs/nshmp-ws-utils';
import {internalApps} from 'projects/nshmp-apps/src/shared/utils/applications.utils';

import {AppService} from '../../services/app.service';

@Component({
  imports: [
    MatAccordion,
    MatExpansionPanel,
    MatExpansionPanelHeader,
    MatExpansionPanelTitle,
    MatDivider,
    MatCard,
    MatCardHeader,
    MatCardContent,
    MatCardTitle,
    MatCardActions,
    YamlPipe,
    RouterLink,
    MatButton,
    MatIcon,
    MatMiniFabButton,
    MatTooltip,
  ],
  selector: 'app-history',
  standalone: true,
  styleUrl: './history.component.scss',
  templateUrl: './history.component.html',
})
export class HistoryComponent {
  awsLinks = internalApps().aws;

  history = this.service.history;

  constructor(
    public service: AppService,
    private nshmpService: NshmpService
  ) {}

  downloadConfiguration(
    serviceResponse: Response<
      RunNshmpHazHttpPostConfig,
      RunNshmpHazResponseData
    >
  ): void {
    const blob = new Blob([JSON.stringify(serviceResponse.request, null, 2)], {
      type: 'text/csv;charset=utf-8;',
    });

    this.nshmpService.saveAs(
      blob,
      `aws-config-${serviceResponse.response.jobId}.json`
    );
  }
}
