import {CdkScrollable} from '@angular/cdk/scrolling';
import {Location} from '@angular/common';
import {Component} from '@angular/core';
import {MatButton} from '@angular/material/button';
import {MatCardModule} from '@angular/material/card';
import {
  MatDialogActions,
  MatDialogClose,
  MatDialogContent,
  MatDialogTitle,
} from '@angular/material/dialog';
import {MatExpansionModule} from '@angular/material/expansion';
import {Router} from '@angular/router';
import {YamlPipe} from '@ghsc/nshmp-lib-ng/aws';
import {RunNshmpHazResponseData} from '@ghsc/nshmp-utils-ts/libs/aws/run-nshmp-haz';
import {internalApps} from 'projects/nshmp-apps/src/shared/utils/applications.utils';

import {AppService} from '../../services/app.service';

/**
 * Angular material dialog content for summary of submitted job configuration.
 */
@Component({
  imports: [
    MatDialogTitle,
    CdkScrollable,
    MatDialogContent,
    MatDialogActions,
    MatButton,
    MatDialogClose,
    YamlPipe,
    MatCardModule,
    MatExpansionModule,
  ],
  selector: 'app-job-submitted',
  standalone: true,
  styleUrl: './job-submitted.component.scss',
  templateUrl: './job-submitted.component.html',
})
export class JobSubmittedComponent {
  serviceResponses = this.service.serviceResponses;

  constructor(
    private service: AppService,
    private router: Router,
    private location: Location
  ) {}

  checkJob(response: RunNshmpHazResponseData) {
    const url = this.router.serializeUrl(
      this.router.createUrlTree(
        [
          this.location.prepareExternalUrl(
            internalApps().aws.checkHazJobs.routerLink
          ),
        ],
        {
          queryParams: {
            id: response.jobId,
          },
        }
      )
    );

    window.open(url, '_blank');
  }
}
