import {Component, OnDestroy, OnInit} from '@angular/core';
import {
  NshmpLibNgAboutContentComponent,
  NshmpLibNgAboutPageComponent,
} from '@ghsc/nshmp-lib-ng/about';
import {
  ApplicationSections,
  NshmpLibNgDashboardComponent,
  NshmpLibNgDashboardDescriptionComponent,
  NshmpLibNgDashboardTitleComponent,
  NshmpLibNgTemplateComponent,
} from '@ghsc/nshmp-lib-ng/nshmp';
import {Subscription} from 'rxjs';

import * as nav from '../../../shared/utils/navigation.utils';
import {AuthService} from '../shared/services/auth.service';

/**
 * Development dashboard showing links to development applications.
 */
@Component({
  imports: [
    NshmpLibNgTemplateComponent,
    NshmpLibNgAboutPageComponent,
    NshmpLibNgAboutContentComponent,
    NshmpLibNgDashboardComponent,
    NshmpLibNgDashboardTitleComponent,
    NshmpLibNgDashboardDescriptionComponent,
  ],
  selector: 'app-app',
  standalone: true,
  styleUrl: './app.component.scss',
  templateUrl: './app.component.html',
})
export class AppComponent implements OnInit, OnDestroy {
  /** Navigation list for menu */
  navigationList = nav.internalNavigation();

  title = 'Internal Applications';

  /** AWS applications */
  private awsApps = nav.internalAwsApps();

  sections: ApplicationSections[] = [];

  private sub: Subscription;

  constructor(private authService: AuthService) {}

  ngOnInit(): void {
    this.sub = this.authService.isAuthorized().subscribe(() => {
      this.sections = [
        {
          sections: [
            {
              applications: this.awsApps.map(navigation => ({navigation})),
            },
          ],
        },
      ];
    });
  }

  ngOnDestroy(): void {
    this.sections = [];
    this.sub.unsubscribe();
  }
}
