import {Component, computed, OnDestroy, OnInit, Signal} from '@angular/core';
import {ReactiveFormsModule} from '@angular/forms';
import {MatButtonModule} from '@angular/material/button';
import {MatFormFieldModule} from '@angular/material/form-field';
import {MatIcon} from '@angular/material/icon';
import {MatInputModule} from '@angular/material/input';
import {MatTooltip} from '@angular/material/tooltip';
import {NshmpLibNgHazardLocationFormComponent} from '@ghsc/nshmp-lib-ng/hazard';
import {
  NshmpLibNgMapSelectSiteComponent,
  SelectSiteDialogData,
} from '@ghsc/nshmp-lib-ng/map';
import {
  FormGroupControls,
  NshmpLibNgControlPanelButtonsComponent,
} from '@ghsc/nshmp-lib-ng/nshmp';
import {NcmUsageParameter} from '@ghsc/nshmp-utils-ts/libs/ncm/geophysical';
import {Location} from '@ghsc/nshmp-utils-ts/libs/nshmp-lib/geo';
import {DoubleParameter} from '@ghsc/nshmp-utils-ts/libs/nshmp-ws-utils/metadata';
import {environment} from 'projects/nshmp-apps/src/environments/environment';
import {Subscription} from 'rxjs';

import {AppService} from '../../services/app.service';

@Component({
  imports: [
    NshmpLibNgHazardLocationFormComponent,
    NshmpLibNgMapSelectSiteComponent,
    NshmpLibNgControlPanelButtonsComponent,
    ReactiveFormsModule,
    MatFormFieldModule,
    MatInputModule,
    MatButtonModule,
    MatIcon,
    MatTooltip,
  ],
  selector: 'app-control-panel',
  standalone: true,
  styleUrl: './control-panel.component.scss',
  templateUrl: './control-panel.component.html',
})
export class ControlPanelComponent implements OnInit, OnDestroy {
  formGroup = this.service.formGroup;

  parameters = computed(() => this.service.usage()?.response?.parameters);

  /** Data for select site component */
  selectSiteData: Signal<SelectSiteDialogData> = computed(() => {
    const usage = this.service.usage();

    if (usage === null) {
      return;
    }

    const ncm = environment.webServices.ncm;
    const mapUrl = `${ncm.url}${ncm.services.mapBounds}`;

    return {
      mapUrl,
    };
  });

  private subs: Subscription[] = [];

  constructor(public service: AppService) {}

  ngOnInit(): void {
    const controls = this.formGroup.controls;

    this.subs.push(
      controls.depthInc.valueChanges.subscribe(() => this.service.resetState())
    );
    this.subs.push(
      controls.depthMax.valueChanges.subscribe(() => this.service.resetState())
    );
    this.subs.push(
      controls.depthMin.valueChanges.subscribe(() => this.service.resetState())
    );
    this.subs.push(
      controls.locations.valueChanges.subscribe(() => this.service.resetState())
    );
  }

  ngOnDestroy(): void {
    this.subs.forEach(sub => sub.unsubscribe());
  }

  removeLocation(index: number): void {
    this.formGroup.controls.locations.removeAt(index);
  }

  setLocation(location: Location, form: FormGroupControls<Location>): void {
    form.patchValue({
      latitude: location.latitude,
      longitude: location.longitude,
    });
  }

  toDoubleParameter(parameter: NcmUsageParameter): DoubleParameter {
    if (parameter === null) {
      return {
        max: null,
        min: null,
        name: '',
        units: '',
      };
    }

    return {
      max: parameter.max,
      min: parameter.min,
      name: parameter.label,
      units: parameter.units,
    };
  }
}
