import {Component, computed} from '@angular/core';
import {
  NshmpLibNgPlotSettingsExpansionPanelComponent,
  NshmpPlot,
  PlotSettingsPlots,
} from '@ghsc/nshmp-lib-ng/plot';

import {AppService} from '../../services/app.service';

@Component({
  imports: [NshmpLibNgPlotSettingsExpansionPanelComponent],
  selector: 'app-plot-settings-panel',
  standalone: true,
  styleUrl: './plot-settings-panel.component.scss',
  templateUrl: './plot-settings-panel.component.html',
})
export class PlotSettingsPanelComponent {
  plots = computed<PlotSettingsPlots[]>(() => {
    const plots = this.service.plots();
    const defaultPlots = this.service.defaultPlots();
    const expanded = false;

    return [
      {
        defaultPlotSetting: defaultPlots.temperature.settingsForm.getRawValue(),
        expanded,
        plot: plots.temperature,
        updatePlot: plot => this.updateTemperature(plot),
      },
      {
        defaultPlotSetting: defaultPlots.porosity.settingsForm.getRawValue(),
        expanded,
        plot: plots.porosity,
        updatePlot: plot => this.updatePorosity(plot),
      },
      {
        defaultPlotSetting: defaultPlots.vs.settingsForm.getRawValue(),
        expanded,
        plot: plots.vs,
        updatePlot: plot => this.updateVs(plot),
      },
      {
        defaultPlotSetting: defaultPlots.vp.settingsForm.getRawValue(),
        expanded,
        plot: plots.vp,
        updatePlot: plot => this.updateVp(plot),
      },
      {
        defaultPlotSetting: defaultPlots.density.settingsForm.getRawValue(),
        expanded,
        plot: plots.density,
        updatePlot: plot => this.updateDensity(plot),
      },
    ];
  });

  constructor(public service: AppService) {}

  updateDensity(density: NshmpPlot): void {
    this.service.updateState({
      plots: {
        ...this.service.plots(),
        density,
      },
    });
  }

  updatePorosity(porosity: NshmpPlot): void {
    this.service.updateState({
      plots: {
        ...this.service.plots(),
        porosity,
      },
    });
  }

  updateTemperature(temperature: NshmpPlot): void {
    this.service.updateState({
      plots: {
        ...this.service.plots(),
        temperature,
      },
    });
  }

  updateVp(vp: NshmpPlot): void {
    this.service.updateState({
      plots: {
        ...this.service.plots(),
        vp,
      },
    });
  }

  updateVs(vs: NshmpPlot): void {
    this.service.updateState({
      plots: {
        ...this.service.plots(),
        vs,
      },
    });
  }
}
