import {Component, computed} from '@angular/core';
import {MatTabsModule} from '@angular/material/tabs';
import {NshmpLibNgDataTablePanelComponent} from '@ghsc/nshmp-lib-ng/nshmp';
import {plotUtils} from '@ghsc/nshmp-lib-ng/plot';

import {AppService} from '../../services/app.service';
import {PlotsComponent} from '../plots/plots.component';

@Component({
  imports: [MatTabsModule, PlotsComponent, NshmpLibNgDataTablePanelComponent],
  selector: 'app-content',
  standalone: true,
  styleUrl: './content.component.scss',
  templateUrl: './content.component.html',
})
export class ContentComponent {
  hasData = this.service.hasData;

  parameters = computed(() => {
    const {distance, latitude, longitude, model, timespan} =
      this.service.formGroup.getRawValue();

    return `${model} ${longitude} ${latitude} ${distance}km ${timespan}yr`;
  });

  probabilityTableData = computed(() =>
    plotUtils.plotDataToTableData(this.service.plots().probability, {
      addLabel: true,
    })
  );

  rateTableData = computed(() =>
    plotUtils.plotDataToTableData(this.service.plots().rate, {
      addLabel: true,
      yLabelTransform: () => 'Rate (1/yr)',
      yValueFormat: (y: number) => y.toExponential(4),
    })
  );

  constructor(private service: AppService) {}
}
