import {Component, computed, Signal} from '@angular/core';
import {
  NshmpLibNgPlotSettingsExpansionPanelComponent,
  NshmpPlot,
  PlotSettingsPlots,
} from '@ghsc/nshmp-lib-ng/plot';

import {AppService} from '../../services/app.service';

@Component({
  imports: [NshmpLibNgPlotSettingsExpansionPanelComponent],
  selector: 'app-plot-settings-panel',
  standalone: true,
  styleUrl: './plot-settings-panel.component.scss',
  templateUrl: './plot-settings-panel.component.html',
})
export class PlotSettingsPanelComponent {
  plots: Signal<PlotSettingsPlots[]> = computed(() => {
    const plots = this.service.plots();
    const defaultPlots = this.service.defaultPlots();

    return [
      {
        defaultPlotSetting: defaultPlots.rate.settingsForm.getRawValue(),
        plot: plots.rate,
        updatePlot: plot => this.updateRatePlot(plot),
      },
      {
        defaultPlotSetting: defaultPlots.probability.settingsForm.getRawValue(),
        plot: plots.probability,
        updatePlot: plot => this.updateProbabilityPlot(plot),
      },
    ];
  });

  constructor(private service: AppService) {}

  updateRatePlot(rate: NshmpPlot): void {
    this.service.updateState({
      plots: {
        ...this.service.plots(),
        rate,
      },
    });
    this.service.createPlots();
  }

  updateProbabilityPlot(probability: NshmpPlot): void {
    this.service.updateState({
      plots: {
        ...this.service.plots(),
        probability,
      },
    });
    this.service.createPlots();
  }
}
