import {WebServices} from '../shared/models/web-services.model';

/**
 * Web services for applications to call.
 */
export function webServices(baseUrl: string): WebServices {
  const webServices: WebServices = {
    aashto2023: {
      contextPath: '/ws/designmaps/aashto-2023',
      label: 'AASHTO 2023 Services',
      services: {
        spectra: '/spectra',
        swagger: '/swagger',
      },
      url: `${baseUrl}/ws/designmaps/aashto-2023`,
    },
    aws: {
      contextPath: '/ws/nshmp/hazard-runs',
      label: 'AWS Services',
      services: {
        auth: '/auth',
        getInputFile: '/get-hazard-input-file',
        hazardJobs: '/jobs',
        hazardLogs: '/nshmp-haz-logs',
        hazardResults: '/hazard-results',
        runHazardJobs: '/run-nshmp-haz',
        terminateJob: '/terminate-job',
        uploadInputFile: '/upload-hazard-input-file',
      },
      url: `${baseUrl}/ws/nshmp/hazard-runs`,
    },
    baseUrl,
    data: {
      contextPath: '/ws/nshmp/data',
      label: 'NSHMP Data Services',
      services: {
        faultSections: '/fault-sections',
        gmmDistance: '/gmm/distance',
        gmmHwFw: '/gmm/hw-fw',
        gmmMagnitude: '/gmm/magnitude',
        gmmSpectra: '/gmm/spectra',
        swagger: '/swagger',
        testsites: '/util/testsites',
      },
      url: `${baseUrl}/ws/nshmp/data`,
    },
    hazardTiles: 'https://earthquake.usgs.gov/arcgis/rest/services/haz',
    latestEarthquakes: `${baseUrl}/earthquakes/feed/v1.0/summary`,
    ncm: {
      contextPath: '/ws/nshmp/ncm',
      label: 'National Crustal Model Services',
      services: {
        geologicFramework: '/geologic-framework',
        geophysical: '/geophysical',
        mapBounds: '/map',
        mineral: '/mineral',
        swagger: '/swagger',
        thermalModel: '/thermal-model',
      },
      url: `${baseUrl}/ws/nshmp/ncm`,
    },
    nshmpHazWs: {
      contextPath: '/ws/nshmp/hazard/dynamic',
      label: 'NSHMP Dynamic NSHMs',
      services: {
        curveServices: {
          disagg: '/disagg',
          features: '/features',
          hazard: '/hazard',
          map: '/map',
          mfds: '/trees/mfds',
          probability: '/probability',
          rate: '/rate',
          sites: '/sites',
          sourceModel: '/source',
          swagger: '/swagger',
          trees: '/trees',
        },
        nshms: '/nshms',
      },
      url: `${baseUrl}/ws/nshmp/hazard/dynamic`,
    },
    nshmpWsStatic: {
      contextPath: '/ws/nshmp/hazard/static',
      label: 'NSHMP Static NSHMs',
      services: {
        curveServices: {
          hazard: '/hazard',
          map: '/map',
          sites: '/sites',
          swagger: '/swagger',
        },
        nshms: '/nshms',
      },
      url: `${baseUrl}/ws/nshmp/hazard/static`,
    },
    rtgm: {
      contextPath: '/ws/nshmp/designmaps/rtgm',
      label: 'Risk-Targeted Ground Motion',
      services: {
        calculate: '/calculate',
        swagger: '/swagger',
      },
      url: `${baseUrl}/ws/nshmp/designmaps/rtgm`,
    },
  };

  return webServices;
}
