import {
  AbstractControl,
  ValidationErrors,
  ValidatorFn,
  Validators,
} from '@angular/forms';
import {NshmpPlot} from '@ghsc/nshmp-lib-ng/plot';

export interface ResetPlotSettingsProps {
  currentPlots: Map<string, NshmpPlot>;
  defaultPlots: Map<string, NshmpPlot>;
}

export class SharedService {
  resetPlotSetting(currentPlot: NshmpPlot, defaultPlot: NshmpPlot): void {
    const defaultSettings = defaultPlot.settingsForm;
    currentPlot.settingsForm.markAsPristine();
    currentPlot.settingsForm.markAsUntouched();
    currentPlot.settingsForm.patchValue(defaultSettings.getRawValue());
  }

  resetPlotSettings(props: ResetPlotSettingsProps): void {
    props.currentPlots.forEach((plot, id) => {
      const defaultPlot = props.defaultPlots.get(id);
      this.resetPlotSetting(plot, defaultPlot);
    });
  }

  validateNan(): ValidatorFn {
    return (
      control: AbstractControl<number, number>
    ): ValidationErrors | null => {
      return isNaN(control.value) ? {nan: {value: control.value}} : null;
    };
  }

  validateRequired(): ValidatorFn {
    return (control: AbstractControl) => Validators.required(control);
  }
}
